# Wattssap send message Pro Lite

Criado por Auto Dev uma biblioteca basica de envio de mensagens para o wattssap para finalidade de bots de grupo simples e facil de mexer.

* pip install watssap_auto_dev
